# stylelens-feature
This is a API document for Object Detection on fashion items\"

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.0.1
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import stylelens_feature 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import stylelens_feature
```

## Getting Started

### Prerequisite
Download classification model
```sh
$ cd /path/to/yourpath
$ wget https://s3.ap-northeast-2.amazonaws.com/bluelens-style-model/classification/inception_v3/classify_image_graph_def.pb
```
Define a environment variable
```sh
$ export CLASSIFY_GRAPH=/path/to/yourpath/classify_image_graph_def.pb
```

### Write your code 
```python
from __future__ import print_function
from stylelens_feature import feature_extract

file = '/Users/bok95/Desktop/img.jpg'

extractor = feature_extract.ExtractFeature()

feature = extractor.extract_feature(file)
```

## Author
master@bluehack.net

